@@ -1,9 +1,10 @@
 import os
+from pathlib import Path
 
 import mysql.connector
 from dotenv import load_dotenv
 
-load_dotenv()
+load_dotenv(dotenv_path=Path.home() / ".dataforge.env")
 
 
 def _env_value(*keys: str, default: str | None = None) -> str | None:
